@@ -1,7 +1,10 @@
 #ifndef H_LOGROTATE
 #define H_LOGROTATE
 
+#include <sys/types.h>
+
 #define LOG_FLAG_COMPRESS	(1 << 0)
+#define LOG_FLAG_CREATE		(1 << 1)
 
 #define COMPRESS_COMMAND "gzip -9"
 #define COMPRESS_EXT ".gz"
@@ -18,6 +21,9 @@ typedef struct {
     char * logAddress;
     char * errAddress;
     int flags;
+    mode_t createMode;		/* if any/all of these are -1, we use the */
+    uid_t createUid;		/* attributes from the log file just rotated */
+    gid_t createGid;
 } logInfo;
 
 int readConfigPath(char * path, logInfo * defConfig, 
